@@ -1,14 +1,17 @@
-use std::pin::Pin;
 use std::sync::Arc;
 use std::task::{Context, Poll};
 
 use derive_builder::Builder;
-use futures::{Future, FutureExt, TryFutureExt};
+use futures::{FutureExt, TryFutureExt};
 use metriki_core::metrics::TimerContextArc;
 use metriki_core::MetricsRegistry;
 use tower_layer::Layer;
 use tower_service::Service;
 
+mod common;
+
+use common::ResultFuture;
+
 #[derive(Debug, Clone)]
 pub struct MetricsService<S> {
     registry: Arc<MetricsRegistry>,
@@ -22,7 +25,6 @@ impl<S> MetricsService<S> {
     }
 }
 
-type ResultFuture<R, E> = Pin<Box<dyn Future<Output = Result<R, E>> + Send>>;
 impl<S, R> Service<R> for MetricsService<S>
 where
     S: Service<R> + Send,
@@ -68,6 +70,7 @@ where
 ///
 /// The timer name is provided with option `base_metric_name`, default to `requests`.
 /// The error meter is named as `{timer_name}.error`.
+///
 #[derive(Builder, Debug, Clone)]
 pub struct MetricsLayer {
     registry: Arc<MetricsRegistry>,
@@ -86,3 +89,7 @@ impl<S> Layer<S> for MetricsLayer {
         }
     }
 }
+
+/// The `http` module provides tower service and layer designed for using with Hyper.
+#[cfg(feature = "http")]
+pub mod http;
